<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Criptografia OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Criação de chave privada iniciada</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Criação de chave privada finalizada</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar comunicação privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar comunicação privada automaticamente</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Solicitar comunicação privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Criptografia OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Política de conta de usuário</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar comunicação privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar comunicação privada automaticamente</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Solicitar comunicação privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Criptografia OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Iniciar conversa privada</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Encerrar conversa privada</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Verificar identidade do contato</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Atualizar conversa privada</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>Não-verificado</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Privado</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>Não privado</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Erro ao criptografar mensagem</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Voce enviou dados criptografados para %1, que não estava esperando por isso</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Voce enviou uma mensagem criptografada ilegível</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Voce enviou uma mensagem mal formada</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Mensagem não criptografas para %1 não são permitidas. Tentando iniciar conversa privada...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Erro de criptografia. Mensagem não enviada.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>Mensagem não foi enviada. Conversa privada foi fechada por %1. Reinicie ou feche sua conversa privada.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Erro ao estabelecer conversa privada com %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Nós estamos recebendo nossas próprias mensagens OTR de %1. Reinicie ou fecha sua conversa privada.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>Última mensagem foi reenviada: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>Mensagem de %1 estava ilegível porque você não está com a comunicação privada habilitada.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>Mensagem de %1 estava ilegível.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>Mensagem de %1 estava mal formada.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Erro de criptografia: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>Mensagem de %1 não estava criptografada.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>Mensagem de %1 estava irreconhecível.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 enviou uma mensagem destinada à outra seção. Se você está conectado em mais de uma seção, outra seção pode ter recebido esta mensagem.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Mensagem mal formada recebida</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[reenviado]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Criptografia OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: tentando iniciar conversa privada</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: tentando atualizar conversa privada</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: a outra ponta encerrou a conversa privada; você devia fazer o mesmo</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: conversa privada iniciada</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: conversa privada parada</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: conversa continua privada</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: criando chave privada, isso pode levar alguns minutos</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: chave privada criada, você pode iniciar uma conversa privada agora</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: criação de chave privada falhou</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de impressão digital</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Sua chave de impressão digital (%1: %2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Chave de impressão digital (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>Não tenho certeza se a chave de impressão digital pertence a %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Eu confirmo que a chave de impressão digital pertence a %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Progresso de verificação</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Verificação em progresso...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Fazer pergunta</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pergunta e resposta</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Pergunta que apenas %1 pode responder</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Resposta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Responda a pergunta:</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Atenda a Pergunta e resposta</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 deseja verificar sua identidade usando o método Pergunta e Resposta</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>Pergunta de %1:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Resposta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Enviar segredo compartilhado</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Atender a segredo compartilhado</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 deseja verificar sua identidade usando o método Segredo compartilhado.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Segredo compartilhado que é apenas conhecido por você e %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Resultado da verificação</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>Verificação de %1 falhou. Você provavelmente está conversando com um impostor. Feche a conversa ou tente outro método de verificação.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 verificou você. Você devia fazer o mesmo.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>Verificação de %1 bem sucedida.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Desconhecido.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Selecione o método de verificação</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pergunta e resposta</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Segredo compartilhado</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de impressão digital</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Faça uma pergunta que apenas você e ele(a) sabem a resposta. Se a outra ponta responder corretamente, ele(a) será marcado(a) como verificado.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Compartilhe uma mensagem secreta com a outra ponta. Esta mensagem deverá ser combinada por outro canal seguro (pessoalmente ou por telefone).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Verifique a impressão digital da outra ponta. A troca de informações da impressão digital deverá ocorrer por outro canal seguro (pessoalmente ou por telefone).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Peça o segredo compartilhado</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Segredo compartilhado</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Segredo compartilhado que é apenas conhecido por você e %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Verificar identidade de %1</translation>
    </message>
</context>
<context>
    <name>OtrPluginObject</name>
    <message>
        <source>OTR encryption library could not be initialized</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>